@@ -112,16 +112,16 @@ def get_eq_info():
 coef = np.array([0.02975907, -1.47542641, 19.58163225, 21.7626419])
 
 
-def テストの点数(勉強時間):
+def test_score(h):
     """
     勉強時間に対する，テストの点数を返す
     100点満点，10時間で限界効用逓減によって下がって行く。
     """
-    点数 = int(np.poly1d(coef)(勉強時間))+1
-    return 点数
+    score = int(np.poly1d(coef)(h))+1
+    return score
 
 
-def テストの点数2(勉強時間, 集中力):
-    点数 = int(np.poly1d(coef)(勉強時間))+1-20
-    点数 = 点数*(集中力/100)+20
-    return 点数
\ No newline at end of file
+def test_score2(h, i):
+    score = int(np.poly1d(coef)(h))+1-20
+    score = score*(i/100)+20
+    return score
\ No newline at end of file
